@@ -85,7 +85,7 @@ class Job():
     def _create_mappings(self):
         self.mappings = {}
         for chain in self._unp_mappings:
-            self.mappings[chain.chain_id] = -chain.unp_start + chain.start.residue_number
+            self.mappings[chain.struct_asym_id] = -chain.unp_start + chain.start.residue_number
 
     def _check_bounds(self, unp_pos: int):
         if not self.in_structure(unp_pos):
@@ -102,16 +102,16 @@ class Job():
             return False
         self._check_bounds(unp_pos)
         for res in res_list:
-            if res.position == self.unp_to_pdb(res.chain, unp_pos):
+            if res.chain in self.mappings.keys() and res.position == self.unp_to_pdb(res.chain, unp_pos):
                 return True
         return False
 
     def struct_res(self, unp_pos: int) -> List[Residue]:
         self._check_bounds(unp_pos)
         r = []
-        for _, residues in self.results.pdb.chains.items():
+        for chain, residues in self.results.pdb.chains.items():
             for _, chain_res in residues.items():
-                if chain_res.position == self.unp_to_pdb(chain_res.chain, unp_pos):
+                if chain in self.mappings.keys() and chain_res.position == self.unp_to_pdb(chain_res.chain, unp_pos):
                     r.append(chain_res)
         return r
 
